@@ -1,4 +1,4 @@
-from streams_explorer.core.extractor.extractor import Extractor
+from streams_explorer.core.extractor.extractor import ConnectorExtractor
 from streams_explorer.models.kafka_connector import (
     KafkaConnector,
     KafkaConnectorTypesEnum,
@@ -6,15 +6,14 @@ from streams_explorer.models.kafka_connector import (
 from streams_explorer.models.sink import Sink
 
 
-class JdbcSink(Extractor):
+class JdbcSink(ConnectorExtractor):
     def on_connector_info_parsing(
         self, info: dict, connector_name: str
     ) -> KafkaConnector | None:
         config = info["config"]
         connector_class = config.get("connector.class")
         if connector_class and "JdbcSinkConnector" in connector_class:
-            name = config.get("table.name.format")
-            if name:
+            if name := config.get("table.name.format"):
                 self.sinks.append(
                     Sink(
                         name=name,
