@@ -1,10 +1,12 @@
+from abc import abstractmethod
 from collections import defaultdict
 
 from streams_explorer.core.k8s_app import K8sApp
 from streams_explorer.models.node_information import NodeInfoListItem
+from streams_explorer.plugins import Plugin
 
 
-class LinkingService:
+class LinkingService(Plugin):
     def __init__(self) -> None:
         self.sink_source_redirects: set[str] = set()
         self._connector_info: list[NodeInfoListItem] = []
@@ -48,19 +50,23 @@ class LinkingService:
     ) -> None:
         self._sink_source_info = defaultdict(list, sink_source_info)
 
+    @abstractmethod
     def get_redirect_connector(self, config: dict, link_type: str) -> str | None:
-        pass
+        ...
 
+    @abstractmethod
     def get_redirect_topic(self, topic_name: str, link_type: str) -> str | None:
-        pass
+        ...
 
+    @abstractmethod
     def get_redirect_streaming_app(self, k8s_app: K8sApp, link_type: str) -> str | None:
-        pass
+        ...
 
+    @abstractmethod
     def get_sink_source_redirects(
         self, node_type: str, sink_source_name: str
     ) -> str | None:
-        pass
+        ...
 
     def add_streaming_app_info_item(self, info_item: NodeInfoListItem) -> None:
         self._streaming_app_info.append(info_item)
